```python
impyute.deletion.complete_case

impyute.imputation.ts.locf
impyute.imputation.ts.moving_window

impyute.imputation.cs.em
impyute.imputation.cs.mice
impyute.imputation.cs.fast_knn
impyute.imputation.cs.mean
impyute.imputation.cs.median

impyute.imputation.cs.mode
impyute.imputation.cs.random

data = np.arange(25).reshape((5, 5)).astype(np.float)
data[0][2] =  np.nan

```